pub struct EventBatch {
pub account_id: AccountId,
pub case_key: CaseKey,
pub command_id: CommandId,
pub revision: CaseRevision,
pub events: Vec<CommittedEvent<Value>>,
}Expand description
The events one command committed, with the revision they produced.
Fields
account_id: AccountIdOwning tenant.
case_key: CaseKeyThe case.
command_id: CommandIdThe command that produced the events.
revision: CaseRevisionRevision after the commit.
events: Vec<CommittedEvent<Value>>The events, in commit order.
Implementations
Sourceimpl EventBatch
impl EventBatch
Sourcepub fn new(
account_id: AccountId,
case_key: CaseKey,
command_id: CommandId,
revision: CaseRevision,
events: Vec<CommittedEvent<Value>>,
) -> Self
pub fn new( account_id: AccountId, case_key: CaseKey, command_id: CommandId, revision: CaseRevision, events: Vec<CommittedEvent<Value>>, ) -> Self
Builds a batch from an already erased list of events.
Sourcepub fn from_commit<S, E: Serialize>(
account_id: AccountId,
case_key: CaseKey,
command_id: CommandId,
commit: &Commit<S, E>,
) -> Result<Self, StoreError>
pub fn from_commit<S, E: Serialize>( account_id: AccountId, case_key: CaseKey, command_id: CommandId, commit: &Commit<S, E>, ) -> Result<Self, StoreError>